rpsftm()Calculates the Estimating Equation to be solved in RPSFTM models
est_eqn(psi, data, formula, target = 0, test = "survdiff", autoswitch, ...)A scalar value of the estimating equation: the z-statistics from a test minus a target value
the parameter that measures how more rapidly the lifetime is expended under treatment
the data set that contains the variables. Must contain columns named: time, censor_time,rx, arm. Optionally a column named: treat_modifier
a formula object of covariates to adjust for: ~strata(A)+B*C
the value to subtract off from the z-statistic
the survival regression function to calculate the z-statistic: survdiff, coxph, survreg
a logical to autodetect cases of no switching. If TRUE, then if all observations in an arm have perfect compliance then recensoring is not applied in that arm. If FALSE the recensoring is applied regardless of perfect compliance.
arguments to supply to the test function.
Simon Bond
untreated