Learn R Programming

rpsftm (version 1.2.7)

extract_z: Extracting the z-statistic from a survival object

Description

Generic S3 methods to extract the z-statistic from a set of survival fit objects

Usage

extract_z(x, ...)

# S3 method for survdiff extract_z(fit, ...)

# S3 method for coxph extract_z(fit, arm, ...)

# S3 method for survreg extract_z(fit, arm, ...)

Value

a numeric value, the z statistic for the independence test of the treatment arm

Arguments

x

an R object

...

extendible arguments to the S3 method

fit

a fitted survival object : survdiff, coxph, survreg

arm

a character vector giving the name of the covariate representing the treatment arm.

Methods (by class)

  • survdiff: Method for survdiff

  • coxph: Method for coxph objects

  • survreg: Method for survreg objects

Author

Simon Bond