Learn R Programming

rpsftm (version 1.2.9)

print.rpsftm: Print Method

Description

Function used to print of the underlying test object at the point estimate of a rpsftm object

Usage

# S3 method for rpsftm
print(x, ...)

Value

a print of the underlying test object at the point estimate.

Arguments

x

an object returned from the rpsftm function.

...

further arguments passed to or from other methods.

Author

Simon Bond