This implements the method of Robins JM, Tsiatis AA.
The key function is rpsftm, which provides estimates of the causal parameter of interest.
Maintainer: Simon Bond simon.bond7@nhs.net (primary author of code, secondary author of vignette)
Authors:
Annabel Allison (primary author of vignette, secondary author of code)
rpfstm: a package to fit Rank Preserving Structural Failure Time Model
Robins JM, Tsiatis AA. Correcting for non-compliance in randomized trials using rank preserving structural failure time models. Communications in Statistics--Theory and Methods 1991; 20: 2609--2631