The function uniroot_all searches the interval from lower to upper for several roots of a function f with respect to its first argument.
uniroot_all(
f,
interval,
lower = min(interval),
upper = max(interval),
tol = .Machine$double.eps^0.2,
maxiter = 1000,
trace = 0,
n = 100,
...
)a vector with the roots found in the interval.
the function for which the root is sought. This function needs to accept a vector of input values.
a vector containing the end-points of the interval to be searched for the root.
the lower end point of the interval to be searched.
the upper end poitn of the interval to be searched.
the desired accuracy (convergence tolerance). Passed to function uniroot.
integer numberl if positive, tracing information is produced. Higher values giving more details. Passed to function uniroot.
number of subintervals in which the root is sought.
additional named or unnamed arguments to be passed to f (but beware of parital matching to other arguments).
Karline Soetaert <karline.soetaert@nioz.nl> - original . Copied by Simon Bond.
this is a copy taken from the package rootSolve but imported here to avoid dependency