Generic S3 methods to extract the z-statistic from a set of survival fit objects
extract_z(x, ...)# S3 method for survdiff
extract_z(fit, ...)
# S3 method for coxph
extract_z(fit, arm, ...)
# S3 method for survreg
extract_z(fit, arm, ...)
a numeric value, the z statistic for the independence test of the treatment arm
an R object
extendible arguments to the S3 method
a fitted survival object : survdiff, coxph, survreg
a character vector giving the name of the covariate representing the treatment arm.
survdiff: Method for survdiff
coxph: Method for coxph objects
survreg: Method for survreg objects
Simon Bond