Learn R Programming

rpsftm (version 1.2.7)

terms.inner: terms.inner

Description

A function taken from the survival library - it is not exported from there hence a local copy

Usage

# S3 method for inner
terms(x)

Value

a list of variables referred to in a formula or call object

a character vector

Arguments

x

an R object