powered by
A function taken from the survival library - it is not exported from there hence a local copy
# S3 method for inner terms(x)
a list of variables referred to in a formula or call object
a character vector
an R object